@@ -76,12 +76,12 @@ void ElementEditor::contextMenu(QPoint screenPos, QGraphicsItem *itemAtMouse)
     QString colorMenuText(tr("Change color to..."));
     QString frequencyText(tr("Change frequency"));
     QString morphMenuText(tr("Morph to..."));
+    QString priorityText(tr("Change priority"));
     QString renameText(tr("Rename"));
     QString revertSkinText(tr("Set skin to default"));
     QString rotateLeftText(tr("Rotate left"));
     QString rotateRightText(tr("Rotate right"));
     QString triggerText(tr("Change trigger"));
-    QString priorityText(tr("Change priority"));
 
     menu.addAction(priorityText)->setData(priorityText);
 
@@ -98,10 +98,8 @@ void ElementEditor::contextMenu(QPoint screenPos, QGraphicsItem *itemAtMouse)
         menu.addAction(revertSkinText);
     }
 
-    if (m_hasRotation) {
-        menu.addAction(QIcon(QPixmap(":/toolbar/rotateL.svg")), rotateLeftText)->setData(rotateLeftText);
-        menu.addAction(QIcon(QPixmap(":/toolbar/rotateR.svg")), rotateRightText)->setData(rotateRightText);
-    }
+    menu.addAction(QIcon(QPixmap(":/toolbar/rotateL.svg")), rotateLeftText)->setData(rotateLeftText);
+    menu.addAction(QIcon(QPixmap(":/toolbar/rotateR.svg")), rotateRightText)->setData(rotateRightText);
 
     if (m_hasFrequency) {
         menu.addAction(QIcon(ElementFactory::pixmap(ElementType::Clock)), frequencyText)->setData(frequencyText);
@@ -617,18 +615,12 @@ void ElementEditor::setCurrentElements(const QList<GraphicElement *> &elements)
 
     setEnabled(true);
     show();
+
     /* Skin */
     m_ui->pushButtonChangeSkin->setVisible(m_canChangeSkin);
     m_ui->pushButtonDefaultSkin->setVisible(m_canChangeSkin);
 }
 
-void ElementEditor::disable()
-{
-    m_hasElements = false;
-    hide();
-    m_ui->lineEditElementLabel->setText("");
-}
-
 void ElementEditor::selectionChanged()
 {
     setCurrentElements(m_scene->selectedElements());
