@@ -22,7 +22,7 @@
 
 namespace
 {
-int id = qRegisterMetaType<GraphicElement>();
+    int id = qRegisterMetaType<GraphicElement>();
 }
 
 const int maximumValidInputSize = 256;
@@ -125,14 +125,14 @@ void GraphicElement::setOutputs(const QVector<QNEOutputPort *> &outputs)
     m_outputPorts = outputs;
 }
 
-QNEInputPort *GraphicElement::inputPort(const int pos)
+QNEInputPort *GraphicElement::inputPort(const int index)
 {
-    return m_inputPorts.at(pos);
+    return m_inputPorts.at(index);
 }
 
-QNEOutputPort *GraphicElement::outputPort(const int pos)
+QNEOutputPort *GraphicElement::outputPort(const int index)
 {
-    return m_outputPorts.at(pos);
+    return m_outputPorts.at(index);
 }
 
 void GraphicElement::save(QDataStream &stream) const
@@ -302,7 +302,7 @@ void GraphicElement::loadNewFormat(QDataStream &stream, QMap<quint64, QNEPort *>
         if (port < m_inputPorts.size()) {
             m_inputPorts.value(port)->setPtr(ptr);
 
-            if (ElementType() == ElementType::IC) {
+            if (elementType() == ElementType::IC) {
                 m_inputPorts.value(port)->setName(name);
             }
         } else {
@@ -1101,12 +1101,6 @@ void GraphicElement::highlight(const bool isSelected)
             }
 
             connection->setHighLight(isSelected);
-
-            if (auto *otherPort = connection->otherPort(port)) {
-                if (auto *elm = otherPort->graphicElement(); elm && (elm->elementType() == ElementType::Node)) {
-                    elm->highlight(isSelected);
-                }
-            }
         }
     }
 }
