@@ -1,4 +1,4 @@
-// Copyright 2015 - 2021, GIBIS-Unifesp and the wiRedPanda contributors
+// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "logicdlatch.h"
@@ -10,16 +10,22 @@ LogicDLatch::LogicDLatch()
     setOutputValue(1, true);
 }
 
-void LogicDLatch::_updateLogic(const std::vector<bool> &inputs)
+void LogicDLatch::updateLogic()
 {
-    bool q0 = getOutputValue(0);
-    bool q1 = getOutputValue(1);
-    bool D = inputs[0];
-    bool enable = inputs[1];
+    if (!updateInputs()) {
+        return;
+    }
+
+    bool q0 = outputValue(0);
+    bool q1 = outputValue(1);
+    const bool D = m_inputValues.at(0);
+    const bool enable = m_inputValues.at(1);
+
     if (enable) {
         q0 = D;
         q1 = !D;
     }
+
     setOutputValue(0, q0);
     setOutputValue(1, q1);
-}
\ No newline at end of file
+}
