@@ -38,8 +38,8 @@
 
 namespace
 {
-int id = qRegisterMetaType<QNEInputPort>();
-int id2 = qRegisterMetaType<QNEOutputPort>();
+    int id = qRegisterMetaType<QNEInputPort>();
+    int id2 = qRegisterMetaType<QNEOutputPort>();
 }
 
 QNEPort::QNEPort(QGraphicsItem *parent)
@@ -58,11 +58,6 @@ LogicElement *QNEPort::logic() const
     return graphicElement() ? graphicElement()->logic() : nullptr;
 }
 
-int QNEPort::radius() const
-{
-    return m_radius;
-}
-
 const QList<QNEConnection *> &QNEPort::connections() const
 {
     return m_connections;
@@ -101,11 +96,6 @@ int QNEPort::portFlags() const
     return m_portFlags;
 }
 
-quint64 QNEPort::ptr() const
-{
-    return m_ptr;
-}
-
 void QNEPort::setPtr(const quint64 ptr)
 {
     m_ptr = ptr;
