@@ -1,41 +1,32 @@
-/*
- * Copyright 2015 - 2021, GIBIS-Unifesp and the wiRedPanda contributors
- * SPDX-License-Identifier: GPL-3.0-or-later
- */
+// Copyright 2015 - 2022, GIBIS-UNIFESP and the WiRedPanda contributors
+// SPDX-License-Identifier: GPL-3.0-or-later
 
-#ifndef TESTLOGICELEMENTS_H
-#define TESTLOGICELEMENTS_H
-
-#include "logicelement.h"
+#pragma once
 
 #include <QObject>
-#include <QTest>
+#include <QVector>
 
-#include "logicelement/logicinput.h"
+class LogicInput;
 
 class TestLogicElements : public QObject
 {
     Q_OBJECT
 
-    QVector<LogicInput *> sw{5};
-
-public:
-    explicit TestLogicElements(QObject *parent = nullptr);
-
 private slots:
-    void init();
     void cleanup();
-    void testLogicNode();
+    void init();
     void testLogicAnd();
-    void testLogicOr();
-    void testLogicInput();
-    void testLogicMux();
-    void testLogicDemux();
     void testLogicDFlipFlop();
     void testLogicDLatch();
+    void testLogicDemux();
+    void testLogicInput();
     void testLogicJKFlipFlop();
+    void testLogicMux();
+    void testLogicNode();
+    void testLogicOr();
     void testLogicSRFlipFlop();
     void testLogicTFlipFlop();
-};
 
-#endif // TESTLOGICELEMENTS_H
\ No newline at end of file
+private:
+    QVector<LogicInput *> switches{5};
+};
